==> jstyle_4.3.2.0-64bit.zip: org/eclipse/swt/internal/mozilla/nsILocalFile.java <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by Netscape are Copyright (C) 1998-1999
 * Netscape Communications Corporation.  All Rights Reserved.
 *
 * Contributor(s):
 *
 * IBM
 * -  Binding to permit interfacing between Mozilla and SWT
 * -  Copyright (C) 2003, 2013 IBM Corp.  All Rights Reserved.
 *
 * ***** END LICENSE BLOCK ***** */
package org.eclipse.swt.internal.mozilla;

public class nsILocalFile extends nsIFile {

	static final int LAST_METHOD_ID = nsIFile.LAST_METHOD_ID + (IsXULRunner17 ? 0 : 17);

	public static final String NS_ILOCALFILE_IID_STR =
		"aa610f20-a889-11d3-8c81-000064657374";
	
	public static final String NS_ILOCALFILE_17_IID_STR =
		"ce4ef184-7660-445e-9e59-6731bdc65505";

	public static final nsID NS_ILOCALFILE_IID =
		new nsID(NS_ILOCALFILE_IID_STR);
	
	public static final nsID NS_ILOCALFILE_17_IID =
		new nsID(NS_ILOCALFILE_17_IID_STR);

	public nsILocalFile(long /*int*/ address) {
		super(address);
	}
}

==> jstyle_4.4.2.0-32bit.zip: org/eclipse/swt/internal/mozilla/nsILocalFile.java <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by Netscape are Copyright (C) 1998-1999
 * Netscape Communications Corporation.  All Rights Reserved.
 *
 * Contributor(s):
 *
 * IBM
 * -  Binding to permit interfacing between Mozilla and SWT
 * -  Copyright (C) 2003, 2013 IBM Corp.  All Rights Reserved.
 *
 * ***** END LICENSE BLOCK ***** */
package org.eclipse.swt.internal.mozilla;


public class nsILocalFile extends nsIFile {

	static final int LAST_METHOD_ID = nsIFile.LAST_METHOD_ID + (IsXULRunner24() ? 0 : 17);

	static final String NS_ILOCALFILE_IID_STR = "aa610f20-a889-11d3-8c81-000064657374";
	static final String NS_ILOCALFILE_24_IID_STR = "ce4ef184-7660-445e-9e59-6731bdc65505";

	static {
		IIDStore.RegisterIID(nsILocalFile.class, MozillaVersion.VERSION_BASE, new nsID(NS_ILOCALFILE_IID_STR));
		IIDStore.RegisterIID(nsILocalFile.class, MozillaVersion.VERSION_XR24, new nsID(NS_ILOCALFILE_24_IID_STR));
	}

	public nsILocalFile(int /*long*/ address) {
		super(address);
	}
}
